#
# spec file for package libadplug
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
%define soname 2_4-%{sover}
%define libname libadplug%{soname}
Name:           libadplug
Version:        2.4
Release:        1.1
Summary:        AdLib Sound Player Library
License:        LGPL-2.1-only
Group:          System/Libraries
#Git-Clone:     https://github.com/adplug/adplug.git
URL:            https://adplug.github.io/
Source:         https://github.com/adplug/adplug/archive/refs/tags/adplug-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  make
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libbinio)

%description
AdPlug is a hardware independent AdLib sound player library.
AdPlug plays sound data, originally created for the AdLib (OPL2) and
Sound Blaster (Dual OPL2/OPL3) audio boards, directly from its original
format on top of an emulator or by using the real hardware.
No OPL chip is required for playback.

%package -n %{libname}
Summary:        AdLib Sound Player Library
Group:          System/Libraries

%description -n %{libname}
AdPlug is a hardware independent AdLib sound player library.
AdPlug plays sound data, originally created for the AdLib (OPL2) and
Sound Blaster (Dual OPL2/OPL3) audio boards, directly from its original
format on top of an emulator or by using the real hardware.
No OPL chip is required for playback.

%package -n libadplug-devel
Summary:        Development Files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}
Requires:       pkgconfig(libbinio)

%description -n libadplug-devel
AdPlug is a hardware independent AdLib sound player library.
AdPlug plays sound data, originally created for the AdLib (OPL2) and
Sound Blaster (Dual OPL2/OPL3) audio boards, directly from its original
format on top of an emulator or by using the real hardware.
No OPL chip is required for playback.

This subpackage contains libraries and header files for developing
applications that want to make use of libadplug.

%package -n adplugdb
Summary:        AdPlug Database Maintenance Utility
Group:          Productivity/Multimedia/Sound/Utilities

%description -n adplugdb
adplugdb maintains database files in AdPlug database format. It can add, list
and remove records within a central database, or merge a set of databases
together into one single database.

%prep
%autosetup -p1 -n "adplug-adplug-%{version}"

%build
autoreconf -fiv
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post   -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%check
%make_build check

%files -n %{libname}
%license COPYING
%doc ChangeLog NEWS README
%{_libdir}/libadplug-%{version}.so.%{sover}*

%files -n libadplug-devel
%{_includedir}/adplug
%{_libdir}/libadplug.so
%{_libdir}/pkgconfig/adplug.pc
%{_infodir}/libadplug.info%{?ext_info}

%files -n adplugdb
%license COPYING
%doc README
%{_bindir}/adplugdb
%{_mandir}/man1/adplugdb.1%{?ext_man}

%changelog
* Mon Apr  7 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 2.4
  Bug fixes:
  * Many fixes, cleanup, and refactoring across all players based
    on fuzzing tests. Huge thanks to Alexander Miller for these.
    There are too many to list here - please read the commit log.
  * Fixes to SurroundOPL getchip(), fixing missing note problems.
  * Many code typo fixes (thanks to luz paz for these).
  * Make SOP player endian aware and many further fixes across
    players.
  * Fix RAD2 player crashes with files referencing unused
    instruments.
  * Added stress tests and many build fixes across platforms.
  New formats:
  * MUS,ADL: Add support for Coktel Vision game music files to
    Visual Composer player.
  * MID: Detect MIDI Type 1 multi-track files.
  * PIS: Beni Tracker.
  * MTR: Master Tracker Loader.
  * A2M: Add new player for A2M and A2T (versions 1-14).
  * D00: Add support for reheadered D00 songs.
  * PLX: PALLADIX Sound System.
  * LD0: Add support for old LOUDNESS files that don't have MIDI
    instrument data.
  Misc:
  * Updated NukedOPL to master 730f8c238a152cb3314e46919789a666c9d81d82
  * Updated ADL player to ScummVM version from Dec 7, 2020.
- Run checks
* Tue Feb 21 2023 Martin Hauke <mardnh@gmx.de>
- Fix runtime requirements for adplugdb
* Mon Feb 13 2023 Martin Hauke <mardnh@gmx.de>
- Specfile overhaul
- Upstream moved to github: adjust URL, source
- Update to version 2.3.3
  * New RAD player by devinacker
  * Many bug fixes by Alexander Miller
    + CVE-2019-14690 - buffer overflow in .bmf
    + CVE-2019-14691 - buffer overflow in .dtm
    + CVE-2019-14692 - buffer overflow in .mkj
    + CVE-2019-14732 - buffer overflow in .a2m
    + CVE-2019-14733 - buffer overflow in .rad
    + CVE-2019-14734 - buffer overflow in .mtk
    + CVE-2019-15151 - double free and OOB reads in .u6m
    + OOB reads in .xad
    + OOB reads in .rix
- Update to versoin 2.3.2
  * Mostly bug fixes.
- Update to versoin 2.3.1
  * Minor fixes to the build system for performance and
    compatibility.
  * Fix for Linux on more esoteric arches.
- Update to versoin 2.3.0
  * It's been over seven years since the last release, and a lot
    of work has been going on in that time. There are new file
    formats and many bug fixes.
* Sun Oct 14 2018 Markus Rex <msrex@msrex.de>
- remove debug-package definition for non-suse distros
* Wed Jul  9 2008 Pascal Bleser <guru@unixtech.be>
- added missing Requires in -devel subpackage
* Mon Jul  7 2008 Pascal Bleser <guru@unixtech.be>
- new package
